==> krb4-0.7.tar.gz: krb4-0.7/acconfig.h <==
/*  Define this if RETSIGTYPE == void  */
#undef VOID_RETSIGTYPE

/*  Define this if struct utmp have ut_user  */
#undef HAVE_UT_USER

/*  Define this if struct utmp have ut_host  */
#undef HAVE_UT_HOST

/*  Define this if struct utmp have ut_addr  */
#undef HAVE_UT_ADDR

/*  Define this if struct utmp have ut_type  */
#undef HAVE_UT_TYPE

/*  Define this if struct utmp have ut_pid  */
#undef HAVE_UT_PID

/*  Define this if struct utmp have ut_id  */
#undef HAVE_UT_ID

/*  Define this to be the directory where the dictionary for cracklib */
/*  resides */
#undef DICTPATH

/* Define this if you want S/Key support in the login program */
#undef SKEY

/* Define this to the path of the mail spool directory */
#undef KRB4_MAILDIR

/* Define this if `struct sockaddr' includes sa_len */
#undef SOCKADDR_HAS_SA_LEN


@BOTTOM@

#ifdef __STDC__
#define RCSID(msg) static /**/const/**/ char *rcsid[] = { (char *)rcsid, "@(#)" msg }
#else
#define RCSID(msg) static char *rcsid[] = { (char *)rcsid, msg }
#endif

/*
 * Set ORGANIZATION to be the desired organization string printed
 * by the 'kinit' program.  It may have spaces.
 */
#define ORGANIZATION "eBones International"

#if 0
#define KRB_CNF_FILES	{ "/etc/krb.conf",   "/etc/kerberosIV/krb.conf", 0}
#define KRB_RLM_FILES	{ "/etc/krb.realms", "/etc/kerberosIV/krb.realms", 0}
#define KRB_EQUIV	"/etc/krb.equiv"

#define KEYFILE		"/etc/srvtab"

#define KRBDIR		"/var/kerberos"
#define DBM_FILE	KRBDIR "/principal"
#define DEFAULT_ACL_DIR	KRBDIR

#define KRBLOG		"/var/log/kerberos.log"	/* master server  */
#define KRBSLAVELOG	"/var/log/kerberos_slave.log" /* slave server  */
#define KADM_SYSLOG	"/var/log/admin_server.syslog"
#define K_LOGFIL	"/var/log/kpropd.log"
#endif

/* This enables experimental stuff in kadmind, not yet tested (need a
 * multihomed server to test it). Tell bg@sics.se if it works. */
#define MULTIHOMED_KADMIN

/* Maximum values on all known systems */
#define MaxHostNameLen (64+4)
#define MaxPathLen (1024+4)

/*
 * Define NDBM if you are using the 4.3 ndbm library (which is part of
 * libc).  If not defined, 4.2 dbm will be assumed.
 */
/* We are always using the NDBM API. */
#define NDBM

/*
 * Define this if your ndbm-library really is berkeley db and creates
 * files that ends in .db.
 */
#undef HAVE_NEW_DB

/* Define this if you have a working getmsg */
#undef HAVE_GETMSG

/* Define to enable new master key code */
#undef RANDOM_MKEY

/* Location of the master key file, default value lives in <kdc.h> */
#undef MKEYFILE


/*
 * Atleast HPUX does not have setreuid and seteuid
 */

#ifndef HAVE_SETREUID
#ifdef HAVE_SETRESUID
#define setreuid(r, e) setresuid((r), (e), -1)
#else
#define setreuid(r, e) k_setreuid((r), (e))
#endif
#endif

#ifndef HAVE_SETEUID
#ifdef HAVE_SETRESUID
#define seteuid(e) setresuid(-1, (e), -1)
#elif defined(HAVE_SETREUID)
#define seteuid(e) setreuid(-1, (e))
#else
/* this might be:
#define seteuid(e) 0
*/
#error There is no way to set e-uid! (seteuid, setreuid, setresuid)
#endif
#endif

/*
 * AIX braindamage!
 */
#if _AIX
#define _ALL_SOURCE
#define _POSIX_SOURCE
#endif

/*
 * SunOS braindamage! (Sun include files are generally braindead)
 */
#if (defined(sun) || defined(__sun))
#if defined(__svr4__) || defined(__SVR4)
#define SunOS 5
#else
#define SunOS 4
#endif
#endif

==> krb4-0.8.tar.gz: krb4-0.8/acconfig.h <==
/*  Define this if RETSIGTYPE == void  */
#undef VOID_RETSIGTYPE

/*  Define this if struct utmp have ut_user  */
#undef HAVE_UT_USER

/*  Define this if struct utmp have ut_host  */
#undef HAVE_UT_HOST

/*  Define this if struct utmp have ut_addr  */
#undef HAVE_UT_ADDR

/*  Define this if struct utmp have ut_type  */
#undef HAVE_UT_TYPE

/*  Define this if struct utmp have ut_pid  */
#undef HAVE_UT_PID

/*  Define this if struct utmp have ut_id  */
#undef HAVE_UT_ID

/*  Define this to be the directory where the dictionary for cracklib */
/*  resides */
#undef DICTPATH

/* Define this if you want S/Key support in the login program */
#undef SKEY

/* Define this to the path of the mail spool directory */
#undef KRB4_MAILDIR

/* Define this if `struct sockaddr' includes sa_len */
#undef SOCKADDR_HAS_SA_LEN

/* define if getcwd() is broken (such as in SunOS) */
#undef BROKEN_GETCWD

@BOTTOM@

#ifdef __STDC__
#define RCSID(msg) static char *const rcsid[] = { (char *)rcsid, "@(#)" msg }
#else
#define RCSID(msg) static char *rcsid[] = { (char *)rcsid, msg }
#endif

/*
 * Set ORGANIZATION to be the desired organization string printed
 * by the 'kinit' program.  It may have spaces.
 */
#define ORGANIZATION "eBones International"

#if 0
#define KRB_CNF_FILES	{ "/etc/krb.conf",   "/etc/kerberosIV/krb.conf", 0}
#define KRB_RLM_FILES	{ "/etc/krb.realms", "/etc/kerberosIV/krb.realms", 0}
#define KRB_EQUIV	"/etc/krb.equiv"

#define KEYFILE		"/etc/srvtab"

#define KRBDIR		"/var/kerberos"
#define DBM_FILE	KRBDIR "/principal"
#define DEFAULT_ACL_DIR	KRBDIR

#define KRBLOG		"/var/log/kerberos.log"	/* master server  */
#define KRBSLAVELOG	"/var/log/kerberos_slave.log" /* slave server  */
#define KADM_SYSLOG	"/var/log/admin_server.syslog"
#define K_LOGFIL	"/var/log/kpropd.log"
#endif

/* This enables experimental stuff in kadmind, not yet tested (need a
 * multihomed server to test it). Tell bg@sics.se if it works. */
#define MULTIHOMED_KADMIN

/* Maximum values on all known systems */
#define MaxHostNameLen (64+4)
#define MaxPathLen (1024+4)

/*
 * Define NDBM if you are using the 4.3 ndbm library (which is part of
 * libc).  If not defined, 4.2 dbm will be assumed.
 */
#if defined(HAVE_DBM_FIRSTKEY)
#define NDBM
#endif

/*
 * Define this if your ndbm-library really is berkeley db and creates
 * files that ends in .db.
 */
#undef HAVE_NEW_DB

/* Define this if you have a working getmsg */
#undef HAVE_GETMSG

/* Define to enable new master key code */
#undef RANDOM_MKEY

/* Location of the master key file, default value lives in <kdc.h> */
#undef MKEYFILE

#ifdef VOID_RETSIGTYPE
#define SIGRETURN(x) return
#else
#define SIGRETURN(x) return (RETSIGTYPE)(x)
#endif

/*
 * AIX braindamage!
 */
#if _AIX
#define _ALL_SOURCE
#define _POSIX_SOURCE
/* this is left for hysteric reasons :-) */
#define unix /* well, ok... */
#endif

/*
 * SunOS braindamage! (Sun include files are generally braindead)
 */
#if (defined(sun) || defined(__sun))
#if defined(__svr4__) || defined(__SVR4)
#define SunOS 5
#else
#define SunOS 4
#endif
#endif
